All Classes and Interfaces
Class
Description
JDBC based implementation of the
TaskBatchDao.Evaluates if the correct conditions have been met to create a TaskJobLauncher.
Map implementation of the
TaskBatchDao.Provides auto configuration for the
TaskBatchExecutionListener.Auto configuration for
TaskBatchExecutionListener.Maintains the association between a
TaskExecution and a JobExecution
executed within it.Responsible for storing the relationship between a Spring Batch job and the Spring
Cloud task it was executed within.
Injects a configured
TaskBatchExecutionListener into any batch jobs (beans
assignable to AbstractJob) that are executed within the scope of a task.FactoryBean for a TaskBatchExecutionListener.Establish properties to be used for how Tasks work with Spring Batch.
ApplicationRunner to launch Spring Batch jobs.Factory bean for creating an instance of
TaskJobLauncherApplicationRunner.Provides auto configuration for the
TaskJobLauncherApplicationRunner.